@@ -5,35 +5,29 @@ package Unix::Process;
 
 use strict;
 use warnings;
+use AutoLoader;
 use Carp;
 use IPC::System::Simple qw(capture);
 
-our $VERSION    = '1.300_000';
+use version;
+our $VERSION    = version->new("1.2.0")->numify;
 our $PS_PROGRAM = $ENV{PS_PATH} || '/bin/ps';
 our $AUTOLOAD;
 
 1;
 
 sub AUTOLOAD {
-    die "unprocessable garbage: $AUTOLOAD" unless $AUTOLOAD =~ m/::(\w+)$/;
-    my $sub = $1;
+    my $this = shift;
+    my $pid  = shift; $pid = $$ unless $pid and int($pid);
+    my $sub  = $AUTOLOAD;
 
-    my $f = sub {
-        my $this = shift;
-        my $pid  = shift; $pid = $$ unless $pid and int($pid);
-        my $result = eval { capture($PS_PROGRAM, '-o', $sub, '-p', $pid) };
+    $sub = $1 if $sub =~ m/::(\w+)$/;
 
-        croak $@ if $@;
+    my $result = eval { capture($PS_PROGRAM, '-o', $sub, '-p', $pid) };
+    croak $@ if $@;
 
-        return $1 if $result =~ m/[\r\n]\s*(.+?)\s*[\r\n]/ms;
-        return;
-    };
-
-    {
-        no strict 'refs';
-        *$AUTOLOAD = $f;
-    }
-    &$f;
+    return $1 if $result =~ m/[\r\n](.+?)[\r\n]/ms;
+    return;
 }
 
 __END__
